@@ -5,7 +5,6 @@
 #' Internally \code{\link{expand.grid}} is used to compute the combinations, then
 #' \code{\link{batchMap}} is called.
 #'
-#'
 #' @param reg [\code{\link{Registry}}]\cr
 #'   Empty Registry that will store jobs for the mapping.
 #' @param fun [\code{function}]\cr
@@ -24,12 +23,13 @@
 #' # lets store the param grid
 #' grid = batchExpandGrid(reg, f, x = 1:2, y = 1:3, more.args = list(z = 10))
 #' submitJobs(reg)
+#' waitForJobs(reg)
 #' y = reduceResultsVector(reg)
 #' # later, we can always access the param grid like this
 #' grid = getJobParamDf(reg)
 #' cbind(grid, y = y)
 batchExpandGrid = function(reg, fun, ..., more.args = list()) {
-  checkRegistry(reg, strict = TRUE)
+  checkRegistry(reg, strict = TRUE, writeable = TRUE)
   assertFunction(fun)
   args = list(...)
   ns = names(args)
