@@ -1,10 +1,10 @@
-getJobInfoInternal = function(reg, ids, pars, select, unit, columns) {
+getJobInfoInternal = function(reg, ids, select, unit = "seconds", columns) {
   if (!missing(ids))
     ids = checkIds(reg, ids)
   assertChoice(unit, c("seconds", "minutes", "hours", "days", "weeks"))
 
-  select.db   = c("submitted",      "started",      "done",       "done - started AS time_running", "started - submitted AS time_queued", "error",      "node",     "batch_job_id", "r_pid", "seed")
-  select.cns  = c("time.submitted", "time.started", "time.done",  "time.running",                  "time.queued",                        "error.msg",   "nodename", "batch.id",     "r.pid", "seed")
+  select.db   = c("submitted",      "started",      "done",       "CASE WHEN error IS NULL THEN done - started ELSE error_time - started END AS time_running", "memory", "started - submitted AS time_queued", "error",      "error_time",     "node",     "batch_job_id", "r_pid", "seed")
+  select.cns  = c("time.submitted", "time.started", "time.done",  "time.running",                                                                              "memory", "time.queued",                        "error.msg",  "time.error",     "nodename", "batch.id",     "r.pid", "seed")
   columns = c(columns, setNames(select.db, select.cns))
 
   if (!missing(select)) {
@@ -24,6 +24,8 @@ getJobInfoInternal = function(reg, ids, pars, select, unit, columns) {
     tab$time.started = dbConvertNumericToPOSIXct(tab$time.started)
   if (!is.null(tab$time.done))
     tab$time.done = dbConvertNumericToPOSIXct(tab$time.done)
+  if (!is.null(tab$time.error))
+    tab$time.error = dbConvertNumericToPOSIXct(tab$time.error)
 
   # shorten error messages
   if (!is.null(tab$error.msg))
@@ -39,17 +41,22 @@ getJobInfoInternal = function(reg, ids, pars, select, unit, columns) {
   return(tab)
 }
 
-#' Get computational information of jobs.
+#' @title Get computational information of jobs.
 #'
-#' Returns time stamps (submitted, started, done), time running, time in queue,
+#' @description
+#' Returns time stamps (submitted, started, done, error),
+#' time running, approximate memory usage (in Mb),
 #' error messages (shortened, see \code{\link{showLog}} for detailed error messages),
-#' hostname of the host the job was executed, the assigned batch ID, the R PID and the seed of the job.
+#' time in queue, hostname of the host the job was executed,
+#' assigned batch ID, the R PID and the seed of the job.
 #'
-#' @param reg [\code{\link{Registry}}]\cr
-#'   Registry.
-#' @param ids [\code{integer}]\cr
-#'   Ids of jobs.
-#'   Default is all jobs.
+#' To estimate memory usage the sum of the last column of \code{\link[base]{gc}} is used.
+#'
+#' Column \dQuote{time.running} displays the time until either the job was done, or an error occured;
+#' it will by \code{NA} in case of time outs or hard R crashes.
+#'
+#' @template arg_reg
+#' @template arg_ids
 #' @param pars [\code{logical(1)}]\cr
 #'   Include job parameters in the output?
 #'   Default is \code{FALSE}.
@@ -68,6 +75,7 @@ getJobInfoInternal = function(reg, ids, pars, select, unit, columns) {
 #'   \dQuote{days} and \dQuote{weeks}.
 #'   Default is \dQuote{seconds}.
 #' @return [\code{data.frame}].
+#' @family debug
 #' @export
 getJobInfo = function(reg, ids, pars = FALSE, prefix.pars = FALSE, select, unit = "seconds") {
   UseMethod("getJobInfo")
@@ -76,20 +84,21 @@ getJobInfo = function(reg, ids, pars = FALSE, prefix.pars = FALSE, select, unit
 #' @method getJobInfo Registry
 #' @export
 getJobInfo.Registry = function(reg, ids, pars = FALSE, prefix.pars = FALSE, select, unit = "seconds") {
+  checkRegistry(reg, writeable = FALSE)
   syncRegistry(reg)
   assertFlag(pars)
   columns = c(id = "job_id")
   if (pars)
     columns = c(columns, c(pars = "pars"))
 
-  tab = getJobInfoInternal(reg, ids, pars, select, unit, columns)
+  tab = getJobInfoInternal(reg, ids = ids, select = select, unit = unit, columns = columns)
 
-  # unserialize parameters
-  if (pars && !is.null(tab$pars)) {
-    pars = list2df(lapply(tab$pars, function(x) unserialize(charToRaw(x))), force.names = TRUE)
+  if (pars && nrow(tab) > 0L && !is.null(tab$pars)) {
+    pars = deserialize(tab$pars)
     if (prefix.pars)
-      names(pars) = sprintf("job.par.%s", names(pars))
-    tab = cbind(subset(tab, select = -pars), pars)
+      setnames(pars, sprintf("job.par.%s", names(pars)))
+    tab = cbind(dropNamed(tab, "pars"), pars)
   }
+
   return(tab)
 }
